@@ -1,7 +1,7 @@
 package Perinci::Examples::CmdLineSrc;
 
-our $DATE = '2016-02-04'; # DATE
-our $VERSION = '0.69'; # VERSION
+our $DATE = '2016-02-26'; # DATE
+our $VERSION = '0.70'; # VERSION
 
 use 5.010;
 use strict;
@@ -125,6 +125,18 @@ sub cmdline_src_stdin_or_files_array {
     [200, "OK", "a1=[".join(",",@{ $args{a1} })."]", {'func.args'=>\%args}];
 }
 
+$SPEC{cmdline_src_stdin_or_args_array} = {
+    v => 1.1,
+    summary => 'This function has array arg with cmdline_src=stdin_or_args',
+    args => {
+        a1 => {schema=>['array*', of=>'str*'], cmdline_src=>'stdin_or_args'},
+    },
+};
+sub cmdline_src_stdin_or_args_array {
+    my %args = @_;
+    [200, "OK", "a1=[".join(",",@{ $args{a1} })."]", {'func.args'=>\%args}];
+}
+
 $SPEC{cmdline_src_multi_stdin} = {
     v => 1.1,
     summary => 'This function has multiple args with cmdline_src stdin/stdin_or_files',
@@ -213,7 +225,7 @@ Perinci::Examples::CmdLineSrc - Examples for using cmdline_src function property
 
 =head1 VERSION
 
-This document describes version 0.69 of Perinci::Examples::CmdLineSrc (from Perl distribution Perinci-Examples), released on 2016-02-04.
+This document describes version 0.70 of Perinci::Examples::CmdLineSrc (from Perl distribution Perinci-Examples), released on 2016-02-26.
 
 =head1 FUNCTIONS
 
@@ -386,6 +398,32 @@ that contains extra information.
 Return value:  (any)
 
 
+=head2 cmdline_src_stdin_or_args_array(%args) -> [status, msg, result, meta]
+
+This function has array arg with cmdline_src=stdin_or_args.
+
+This function is not exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<a1> => I<array[str]>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
 =head2 cmdline_src_stdin_or_file_array(%args) -> [status, msg, result, meta]
 
 This function has array arg with cmdline_src=stdin_or_file.
